+++
title = "Heat Transfer"
author = ["Dehaeze Thomas"]
draft = false
+++

Tags
:


## Electrical Analogy - Lumped Mass Modeling {#electrical-analogy-lumped-mass-modeling}

The difference in temperature \\(\Delta T\\) is driving potential energy flow \\(Q\\) (in watts):

\begin{equation}
  \Delta T = R\_{th} \cdot Q
\end{equation}

\\(R\_{th}\\) is the analogy of a "thermal resistance", and is expressed in K/W.


## Conduction (diffusion) {#conduction--diffusion}

The _conduction_ corresponds to the heat transfer \\(Q\\) (in watt) through molecular agitation within a material.

\begin{equation}
R\_{th} = \frac{d}{\lambda A}
\end{equation}

with:

-   \\(\lambda\\) the thermal conductivity in \\([W/m \cdot K]\\)
-   \\(A\\) the surface area in \\([m^2]\\)
-   \\(d\\) the length of the barrier in \\([m]\\)


## Convection {#convection}

The convection corresponds to the heat transfer \\(Q\\) through flow of a fluid.
It can be either _natural_ or _forced_.

\begin{equation}
R\_{th} = \frac{1}{h A}
\end{equation}

with:

-   \\(h\\) the convection heat transfer coefficient in \\([W/m^2 \cdot K]\\).
    \\(h \approx 10.5 - v + 10\sqrt{v}\\) with \\(v\\) the velocity of the object through the fluid in \\([m/s]\\)
    Typically:
    -   \\(h = 5 - 10\ W/m^2/K\\) for free convection with air
    -   \\(h = 500 - 5000\ W/m^2/K\\) for forced water cooling in a tube of 5mm diameter
-   \\(A\\) the surface area in \\([m^2]\\)

Note that clean-room air flow should be considered as forced convection, and \\(h \approx 10 W/m^2/K\\).


## Radiation {#radiation}

_Radiation_ corresponds to the heat transfer \\(Q\\) (in watt) through the emission of electromagnetic waves from the emitter to its surroundings.

In the general case, we have:
\\[ Q = \epsilon \cdot \sigma \cdot A \cdot (T\_r^4 - T\_s^4) \\]
with:

-   \\(\epsilon\\) the emissivity which corresponds to the ability of a surface to emit energy through radiation relative to a black body surface at equal temperature.
    It is between 0 (no emissivity) and 1 (maximum emissivity)
-   \\(\sigma\\) the Stefan-Boltzmann constant: \\(\sigma = 5.67 \cdot 10^{-8} \\, \frac{W}{m^2 K^4}\\)
-   \\(T\_r\\) the temperature of the emitter in \\([K]\\)
-   \\(T\_s\\) the temperature of the surrounding in \\([K]\\)

In order to use the lumped mass approximation, the equations can be linearized to obtain:

\begin{equation}
R\_{th} = \frac{1}{h\_{rad} A}
\end{equation}

with:

-   \\(h\_{rad}\\) the effective heat transfer coefficient for radiation in \\(W/m^2 \cdot K\\)
-   \\(A\\) the surface in \\([m^2]\\)


### Practical Cases {#practical-cases}

Two parallel plates:

\begin{equation}
h\_{rad} = \frac{\sigma}{1/\epsilon\_1 + 1/\epsilon\_2 - 1} (T\_1^2 + T\_2^2)(T\_1 + T\_2)
\end{equation}

Two concentric cylinders:

\begin{equation}
h\_{rad} = \frac{\sigma}{1/\epsilon\_1 + r\_1/r\_2 (1/\epsilon\_2 - 1)} (T\_1^2 + T\_2^2)(T\_1 + T\_2)
\end{equation}

A small object enclosed in a large volume:

\begin{equation}
h\_{rad} = \epsilon\_1 \sigma (T\_1^2 + T\_2^2)(T\_1 + T\_2)
\end{equation}


### Emissivity {#emissivity}

The emissivity of materials highly depend on the surface finish (the more polished, the lower the emissivity).
Some examples are given in <tab:emissivity_examples>.

Gold coating gives also a very low emissivity and is typically used in cryogenic applications.

<a id="table--tab:emissivity-examples"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:emissivity-examples">Table 1</a>:</span>
  Some examples of emissivity (specified at 25 degrees)
</div>

| Substance                  | Emissivity |
|----------------------------|------------|
| Silver (polished)          | 0.005      |
| Silver (oxidized)          | 0.04       |
| Stainless Steel (polished) | 0.02       |
| Aluminium (polished)       | 0.02       |
| Aluminium (oxidized)       | 0.2        |
| Aluminium (anodized)       | 0.9        |
| Copper (polished)          | 0.03       |
| Copper (oxidized)          | 0.87       |

<div class="exampl">

Let's take a polished aluminum plate (20 by 20 cm) at 125K (temperature of zero thermal expansion coefficient of silicon) surrounded by elements are 25 degrees (300 K):
\\[ P = \epsilon \cdot \sigma \cdot A \cdot (T\_r^4 - T\_s^4) = 0.36\\, J \\]

</div>


## Heat {#heat}

The _heat_ \\(Q\\) (in Joules) corresponds to the energy necessary to change the temperature of the mass with a certain material specific heat capacity:
\\[ Q = m \cdot c \cdot \Delta T \\]
with:

-   \\(m\\) the mass in \\([kg]\\)
-   \\(c\\) the specific heat capacity in \\([J/kg \cdot K]\\)
-   \\(\Delta T\\) the temperature different \\([K]\\)

<div class="exampl">

Let's compute the heat (i.e. energy) necessary to increase a 1kg granite by 1 degree.
The specific heat capacity of granite is \\(c = 790\\,[J/kg\cdot K]\\).
The required heat is then:
\\[ Q = m\cdot c \cdot \Delta T = 790 \\,J \\]

</div>

<a id="table--tab:specific-heat-capacity"></a>
<div class="table-caption">
  <span class="table-number"><a href="#table--tab:specific-heat-capacity">Table 2</a>:</span>
  Some examples of specific heat capacity
</div>

| Substance           | Specific heat capacity [J/kg.K] |
|---------------------|---------------------------------|
| Air                 | 1012                            |
| Aluminium           | 897                             |
| Copper              | 385                             |
| Granite             | 790                             |
| Steel               | 466                             |
| Water at 25 degrees | 4182                            |


## Heat Transport (i.e. Water cooling) {#heat-transport--i-dot-e-dot-water-cooling}

<a id="figure--fig:heat-transfer-fluid"></a>

{{< figure src="/ox-hugo/heat_transfer_fluid.png" caption="<span class=\"figure-number\">Figure 1: </span>Heat transfered to the fluid" >}}

\begin{equation}
Q\_{in} = h \cdot A \cdot (T\_{wall} - T\_{mean})
\end{equation}

<a id="figure--fig:heat-transport"></a>

{{< figure src="/ox-hugo/heat_transport.png" caption="<span class=\"figure-number\">Figure 2: </span>Heat Transport in the fluid" >}}

\begin{equation}
Q\_{out} = \phi \rho c\_p (T\_{mean,in} - T\_{mean,out})
\end{equation}

with:

-   \\(Q\_{out}\\) the transported heat in W
-   \\(\phi\\) the flow in \\(m^3/s\\)
-   \\(\rho\\) the fluid density in \\(kg/m^3\\)
-   \\(c\_p\\) the specific heat capacity of the fluid in \\(J/(kg \cdot K)\\)
-   \\(T\_{mean}\\) the mean incoming and outgoing fluid temperature

Because of energy balance, we have in the stationary condition: \\(Q\_{in} = Q\_{out}\\)


## Heat flow {#heat-flow}

The heat flow \\(P\\) (in watt) is the derivative of the heat:
\\[ P = \cdot{Q} = \frac{dQ}{dt} = \frac{dT}{R\_T} = C\_T \cdot dT \\]
with:

-   \\(Q\\) the heat in [W]
-   \\(R\_T\\) the thermal resistance in \\([K/W]\\)
-   \\(C\_T\\) the thermal conductance in \\([W/K]\\)


## Bibliography {#bibliography}

<style>.csl-entry{text-indent: -1.5em; margin-left: 1.5em;}</style><div class="csl-bib-body">
</div>
